@@ -1,5 +1,5 @@
 def getEdgeProperty(G,eprop):
-    r"""Given an object of class Graph, it returns an ordered array of edge property
+    """Given an object of class Graph, it returns an ordered array of edge property
     values.
     
     :param G: a graph that contains at least one edge.
